==> gatsby-plugin-intl-fixed-0.0.5.tgz: package/gatsby-node.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var webpack = require("webpack");

function flattenMessages(nestedMessages, prefix) {
  if (prefix === void 0) {
    prefix = "";
  }

  return Object.keys(nestedMessages).reduce(function (messages, key) {
    var value = nestedMessages[key];
    var prefixedKey = prefix ? prefix + "." + key : key;

    if (typeof value === "string") {
      messages[prefixedKey] = value;
    } else {
      Object.assign(messages, flattenMessages(value, prefixedKey));
    }

    return messages;
  }, {});
}

exports.onCreateWebpackConfig = function (_ref, pluginOptions) {
  var actions = _ref.actions,
      plugins = _ref.plugins;
  var _pluginOptions$redire = pluginOptions.redirectComponent,
      redirectComponent = _pluginOptions$redire === void 0 ? null : _pluginOptions$redire,
      languages = pluginOptions.languages,
      defaultLanguage = pluginOptions.defaultLanguage;

  if (!languages.includes(defaultLanguage)) {
    languages.push(defaultLanguage);
  }

  var regex = new RegExp(languages.map(function (l) {
    return l.split("-")[0];
  }).join("|"));
  actions.setWebpackConfig({
    plugins: [plugins.define({
      GATSBY_INTL_REDIRECT_COMPONENT_PATH: JSON.stringify(redirectComponent)
    }), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-relativetimeformat[/\\]dist[/\\]locale-data$/, regex), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-pluralrules[/\\]dist[/\\]locale-data$/, regex)]
  });
};

exports.onCreatePage =
/*#__PURE__*/
function () {
  var _ref2 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(_ref3, pluginOptions) {
    var page, actions, createPage, deletePage, _pluginOptions$path, path, _pluginOptions$langua, languages, _pluginOptions$defaul, defaultLanguage, _pluginOptions$redire2, redirect, _pluginOptions$skip, skip, shouldSkip, _iterator, _isArray, _i, _ref4, s, getMessages, generatePage, newPage;

    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            page = _ref3.page, actions = _ref3.actions;

            if (!(typeof page.context.intl === "object")) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            createPage = actions.createPage, deletePage = actions.deletePage;
            _pluginOptions$path = pluginOptions.path, path = _pluginOptions$path === void 0 ? "." : _pluginOptions$path, _pluginOptions$langua = pluginOptions.languages, languages = _pluginOptions$langua === void 0 ? ["en"] : _pluginOptions$langua, _pluginOptions$defaul = pluginOptions.defaultLanguage, defaultLanguage = _pluginOptions$defaul === void 0 ? "en" : _pluginOptions$defaul, _pluginOptions$redire2 = pluginOptions.redirect, redirect = _pluginOptions$redire2 === void 0 ? false : _pluginOptions$redire2, _pluginOptions$skip = pluginOptions.skip, skip = _pluginOptions$skip === void 0 ? [] : _pluginOptions$skip;
            shouldSkip = false;
            _iterator = skip, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();

          case 7:
            if (!_isArray) {
              _context.next = 13;
              break;
            }

            if (!(_i >= _iterator.length)) {
              _context.next = 10;
              break;
            }

            return _context.abrupt("break", 23);

          case 10:
            _ref4 = _iterator[_i++];
            _context.next = 17;
            break;

          case 13:
            _i = _iterator.next();

            if (!_i.done) {
              _context.next = 16;
              break;
            }

            return _context.abrupt("break", 23);

          case 16:
            _ref4 = _i.value;

          case 17:
            s = _ref4;

            if (!s.test(page.path)) {
              _context.next = 21;
              break;
            }

            shouldSkip = true;
            return _context.abrupt("break", 23);

          case 21:
            _context.next = 7;
            break;

          case 23:
            console.log('Should skip: ', shouldSkip, page.path);

            getMessages = function getMessages(path, language) {
              try {
                // TODO load yaml here
                var messages = require(path + "/" + language + ".json");

                return flattenMessages(messages);
              } catch (error) {
                if (error.code === "MODULE_NOT_FOUND") {
                  process.env.NODE_ENV !== "test" && console.error("[gatsby-plugin-intl] couldn't find file \"" + path + "/" + language + ".json\"");
                }

                throw error;
              }
            };

            generatePage = function generatePage(routed, language, shouldSkip) {
              var messages = getMessages(path, language);
              var newPath = routed ? "/" + language + page.path : page.path;

              if (shouldSkip) {
                console.log('Generate page skipped');
                newPath = page.path;
              }

              return (0, _extends2.default)({}, page, {
                path: newPath,
                context: (0, _extends2.default)({}, page.context, {
                  language: language,
                  intl: {
                    language: language,
                    languages: languages,
                    messages: messages,
                    routed: routed,
                    originalPath: page.path,
                    redirect: redirect,
                    defaultLanguage: defaultLanguage
                  }
                })
              });
            };

            if (!shouldSkip) {
              newPage = generatePage(false, defaultLanguage, shouldSkip);
              deletePage(page);
              createPage(newPage);
            }

            languages.forEach(function (language) {
              if (!shouldSkip) {
                console.log('Intl page created');
                var localePage = generatePage(true, language);
                var regexp = new RegExp("/404/?$");

                if (regexp.test(localePage.path)) {
                  localePage.matchPath = "/" + language + "/*";
                }

                createPage(localePage);
              }
            });

          case 28:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function (_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();

==> gatsby-plugin-intl-fixed-0.0.6.tgz: package/gatsby-node.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var webpack = require("webpack");

function flattenMessages(nestedMessages, prefix) {
  if (prefix === void 0) {
    prefix = "";
  }

  return Object.keys(nestedMessages).reduce(function (messages, key) {
    var value = nestedMessages[key];
    var prefixedKey = prefix ? prefix + "." + key : key;

    if (typeof value === "string") {
      messages[prefixedKey] = value;
    } else {
      Object.assign(messages, flattenMessages(value, prefixedKey));
    }

    return messages;
  }, {});
}

exports.onCreateWebpackConfig = function (_ref, pluginOptions) {
  var actions = _ref.actions,
      plugins = _ref.plugins;
  var _pluginOptions$redire = pluginOptions.redirectComponent,
      redirectComponent = _pluginOptions$redire === void 0 ? null : _pluginOptions$redire,
      languages = pluginOptions.languages,
      defaultLanguage = pluginOptions.defaultLanguage;

  if (!languages.includes(defaultLanguage)) {
    languages.push(defaultLanguage);
  }

  var regex = new RegExp(languages.map(function (l) {
    return l.split("-")[0];
  }).join("|"));
  actions.setWebpackConfig({
    plugins: [plugins.define({
      GATSBY_INTL_REDIRECT_COMPONENT_PATH: JSON.stringify(redirectComponent)
    }), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-relativetimeformat[/\\]dist[/\\]locale-data$/, regex), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-pluralrules[/\\]dist[/\\]locale-data$/, regex)]
  });
};

exports.onCreatePage =
/*#__PURE__*/
function () {
  var _ref2 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(_ref3, pluginOptions) {
    var page, actions, createPage, deletePage, _pluginOptions$path, path, _pluginOptions$langua, languages, _pluginOptions$defaul, defaultLanguage, _pluginOptions$redire2, redirect, _pluginOptions$skip, skip, shouldSkip, _iterator, _isArray, _i, _ref4, s, getMessages, generatePage, newPage;

    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            page = _ref3.page, actions = _ref3.actions;

            if (!(typeof page.context.intl === "object")) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            createPage = actions.createPage, deletePage = actions.deletePage;
            _pluginOptions$path = pluginOptions.path, path = _pluginOptions$path === void 0 ? "." : _pluginOptions$path, _pluginOptions$langua = pluginOptions.languages, languages = _pluginOptions$langua === void 0 ? ["en"] : _pluginOptions$langua, _pluginOptions$defaul = pluginOptions.defaultLanguage, defaultLanguage = _pluginOptions$defaul === void 0 ? "en" : _pluginOptions$defaul, _pluginOptions$redire2 = pluginOptions.redirect, redirect = _pluginOptions$redire2 === void 0 ? false : _pluginOptions$redire2, _pluginOptions$skip = pluginOptions.skip, skip = _pluginOptions$skip === void 0 ? [] : _pluginOptions$skip;
            shouldSkip = false;
            _iterator = skip, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();

          case 7:
            if (!_isArray) {
              _context.next = 13;
              break;
            }

            if (!(_i >= _iterator.length)) {
              _context.next = 10;
              break;
            }

            return _context.abrupt("break", 23);

          case 10:
            _ref4 = _iterator[_i++];
            _context.next = 17;
            break;

          case 13:
            _i = _iterator.next();

            if (!_i.done) {
              _context.next = 16;
              break;
            }

            return _context.abrupt("break", 23);

          case 16:
            _ref4 = _i.value;

          case 17:
            s = _ref4;

            if (!s.test(page.path)) {
              _context.next = 21;
              break;
            }

            shouldSkip = true;
            return _context.abrupt("break", 23);

          case 21:
            _context.next = 7;
            break;

          case 23:
            console.log('Should skip: ', shouldSkip, page.path);

            getMessages = function getMessages(path, language) {
              try {
                // TODO load yaml here
                var messages = require(path + "/" + language + ".json");

                return flattenMessages(messages);
              } catch (error) {
                if (error.code === "MODULE_NOT_FOUND") {
                  process.env.NODE_ENV !== "test" && console.error("[gatsby-plugin-intl] couldn't find file \"" + path + "/" + language + ".json\"");
                }

                throw error;
              }
            };

            generatePage = function generatePage(routed, language, shouldSkip) {
              var messages = getMessages(path, language);
              var newPath = routed ? "/" + language + page.path : page.path;

              if (shouldSkip) {
                console.log('Generate page skipped');
                newPath = page.path;
              }

              page.path = newPath;
              page.context = (0, _extends2.default)({}, page.context, {
                language: language,
                intl: {
                  language: language,
                  languages: languages,
                  messages: messages,
                  routed: routed,
                  originalPath: page.path,
                  redirect: redirect,
                  defaultLanguage: defaultLanguage
                }
              });
              return page;
            };

            newPage = generatePage(false, defaultLanguage, shouldSkip);
            createPage(newPage);
            languages.forEach(function (language) {
              if (!shouldSkip) {
                console.log('Intl page created');
                var localePage = generatePage(true, language);
                var regexp = new RegExp("/404/?$");

                if (regexp.test(localePage.path)) {
                  localePage.matchPath = "/" + language + "/*";
                }

                createPage(localePage);
              }
            });

          case 29:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function (_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();
